# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import nodes_pb2 as nodes__pb2


class NodesStub(object):
    """Nodes make up the StrongDM network, and allow your users to connect securely to your resources.
    There are three types of nodes:
    1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
    2. **Gateway:** a relay that also listens for connections from StrongDM clients
    3. **Proxy Cluster:** a cluster of workers that together mediate access from clients to resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/v1.Nodes/Create',
                request_serializer=nodes__pb2.NodeCreateRequest.SerializeToString,
                response_deserializer=nodes__pb2.NodeCreateResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/v1.Nodes/Get',
                request_serializer=nodes__pb2.NodeGetRequest.SerializeToString,
                response_deserializer=nodes__pb2.NodeGetResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/v1.Nodes/Update',
                request_serializer=nodes__pb2.NodeUpdateRequest.SerializeToString,
                response_deserializer=nodes__pb2.NodeUpdateResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/v1.Nodes/Delete',
                request_serializer=nodes__pb2.NodeDeleteRequest.SerializeToString,
                response_deserializer=nodes__pb2.NodeDeleteResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/v1.Nodes/List',
                request_serializer=nodes__pb2.NodeListRequest.SerializeToString,
                response_deserializer=nodes__pb2.NodeListResponse.FromString,
                )
        self.TCPProbe = channel.unary_unary(
                '/v1.Nodes/TCPProbe',
                request_serializer=nodes__pb2.NodeTCPProbeRequest.SerializeToString,
                response_deserializer=nodes__pb2.NodeTCPProbeResponse.FromString,
                )


class NodesServicer(object):
    """Nodes make up the StrongDM network, and allow your users to connect securely to your resources.
    There are three types of nodes:
    1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
    2. **Gateway:** a relay that also listens for connections from StrongDM clients
    3. **Proxy Cluster:** a cluster of workers that together mediate access from clients to resources
    """

    def Create(self, request, context):
        """Create registers a new Node.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get reads one Node by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update replaces all the fields of a Node by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete removes a Node by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """List gets a list of Nodes matching a given set of criteria.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TCPProbe(self, request, context):
        """TCPProbe instructs a Node to connect to an address via TCP and report the
        result.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NodesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nodes__pb2.NodeCreateRequest.FromString,
                    response_serializer=nodes__pb2.NodeCreateResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nodes__pb2.NodeGetRequest.FromString,
                    response_serializer=nodes__pb2.NodeGetResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nodes__pb2.NodeUpdateRequest.FromString,
                    response_serializer=nodes__pb2.NodeUpdateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nodes__pb2.NodeDeleteRequest.FromString,
                    response_serializer=nodes__pb2.NodeDeleteResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nodes__pb2.NodeListRequest.FromString,
                    response_serializer=nodes__pb2.NodeListResponse.SerializeToString,
            ),
            'TCPProbe': grpc.unary_unary_rpc_method_handler(
                    servicer.TCPProbe,
                    request_deserializer=nodes__pb2.NodeTCPProbeRequest.FromString,
                    response_serializer=nodes__pb2.NodeTCPProbeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.Nodes', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Nodes(object):
    """Nodes make up the StrongDM network, and allow your users to connect securely to your resources.
    There are three types of nodes:
    1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
    2. **Gateway:** a relay that also listens for connections from StrongDM clients
    3. **Proxy Cluster:** a cluster of workers that together mediate access from clients to resources
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Nodes/Create',
            nodes__pb2.NodeCreateRequest.SerializeToString,
            nodes__pb2.NodeCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Nodes/Get',
            nodes__pb2.NodeGetRequest.SerializeToString,
            nodes__pb2.NodeGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Nodes/Update',
            nodes__pb2.NodeUpdateRequest.SerializeToString,
            nodes__pb2.NodeUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Nodes/Delete',
            nodes__pb2.NodeDeleteRequest.SerializeToString,
            nodes__pb2.NodeDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Nodes/List',
            nodes__pb2.NodeListRequest.SerializeToString,
            nodes__pb2.NodeListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TCPProbe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.Nodes/TCPProbe',
            nodes__pb2.NodeTCPProbeRequest.SerializeToString,
            nodes__pb2.NodeTCPProbeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: access_requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61\x63\x63\x65ss_requests.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"i\n\x18\x41\x63\x63\x65ssRequestListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xc9\x01\n\x19\x41\x63\x63\x65ssRequestListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x36\n\x0f\x61\x63\x63\x65ss_requests\x18\x02 \x03(\x0b\x32\x11.v1.AccessRequestB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12@\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\x15\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x83\x05\n\rAccessRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bresource_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06reason\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bworkflow_id\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\naccount_id\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nstart_from\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12@\n\x0bvalid_until\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06status\x18\x08 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\tstatus_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08grant_id\x18\n \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\x08\x64uration\x18\x0b \x01(\x03\x42\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12@\n\x11requestedDuration\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\x0eresultDuration\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x31\n\x0erequester_name\x18\x0c \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xf9\x01\n\x12\x41\x63\x63\x65ssRequestEvent\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nrequest_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08\x61\x63tor_id\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04type\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08metadata\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x43\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xfc\x02\n\x13RequestableResource\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04name\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07healthy\x18\x03 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04type\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0e\x61uthentication\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x06 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06\x61\x63\x63\x65ss\x18\x07 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\nprivileges\x18\x08 \x01(\x0b\x32\x15.v1.PrivilegesMessageB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12@\n\x1dprivileges_requirement_status\x18\t \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xdc\x01\n\x11PrivilegesMessage\x12\x38\n\nkubernetes\x18\x01 \x01(\x0b\x32\x18.v1.KubernetesPrivilegesB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\x0b\x65ntraGroups\x18\x02 \x01(\x0b\x32\x18.v1.EntraGroupPrivilegesB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\noktaGroups\x18\x03 \x01(\x0b\x32\x17.v1.OktaGroupPrivilegesB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"M\n\x14KubernetesPrivileges\x12\x1a\n\x06groups\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"M\n\x14\x45ntraGroupPrivileges\x12\x1a\n\x06groups\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"L\n\x13OktaGroupPrivileges\x12\x1a\n\x06groups\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"\xc3\x01\n\x13\x41\x63\x63\x65ssRequestConfig\x12$\n\x0bresource_id\x18\x01 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06reason\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nstart_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08\x64uration\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xcb\x03\n\x1aRequestAccessRequestConfig\x12\'\n\x0cresource_ids\x18\x01 \x03(\tB\x11\x18\x01\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06reason\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nstart_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08\x64uration\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\xf2\x01\n\x0c\x61\x63\x63\x65ss_rules\x18\x05 \x01(\tB\xdb\x01\xf2\xf8\xb3\x07\xd5\x01\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\xa9\x01\xea\xf3\xb3\x07\x0c\x61\x63\x63\x65ss_rules\xf2\xf3\xb3\x07\x11\n\x02go\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x19\n\ngo_private\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x1b\n\x0cgo_terraform\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x18\n\x04java\x12\x10List<AccessRule>\xf2\xf3\xb3\x07\"\n\x0cjson_gateway\x12\x12models.AccessRules\xba\xf4\xb3\x07\x17\x61\x63\x63\x65ssRulesDiffSuppress\xd0\xf4\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private2\xd9\x01\n\x0e\x41\x63\x63\x65ssRequests\x12o\n\x04List\x12\x1c.v1.AccessRequestListRequest\x1a\x1d.v1.AccessRequestListResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/access-requests\x1aV\xca\xf9\xb3\x07\x12\xc2\xf9\xb3\x07\rAccessRequest\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03\x61q-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-provider\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x92\x01\n\x19\x63om.strongdm.api.plumbingB\x16\x41\x63\x63\x65ssRequestsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ACCESSREQUESTLISTREQUEST = DESCRIPTOR.message_types_by_name['AccessRequestListRequest']
_ACCESSREQUESTLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccessRequestListResponse']
_ACCESSREQUEST = DESCRIPTOR.message_types_by_name['AccessRequest']
_ACCESSREQUESTEVENT = DESCRIPTOR.message_types_by_name['AccessRequestEvent']
_REQUESTABLERESOURCE = DESCRIPTOR.message_types_by_name['RequestableResource']
_PRIVILEGESMESSAGE = DESCRIPTOR.message_types_by_name['PrivilegesMessage']
_KUBERNETESPRIVILEGES = DESCRIPTOR.message_types_by_name['KubernetesPrivileges']
_ENTRAGROUPPRIVILEGES = DESCRIPTOR.message_types_by_name['EntraGroupPrivileges']
_OKTAGROUPPRIVILEGES = DESCRIPTOR.message_types_by_name['OktaGroupPrivileges']
_ACCESSREQUESTCONFIG = DESCRIPTOR.message_types_by_name['AccessRequestConfig']
_REQUESTACCESSREQUESTCONFIG = DESCRIPTOR.message_types_by_name['RequestAccessRequestConfig']
AccessRequestListRequest = _reflection.GeneratedProtocolMessageType('AccessRequestListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTLISTREQUEST,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestListRequest)
  })
_sym_db.RegisterMessage(AccessRequestListRequest)

AccessRequestListResponse = _reflection.GeneratedProtocolMessageType('AccessRequestListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTLISTRESPONSE,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestListResponse)
  })
_sym_db.RegisterMessage(AccessRequestListResponse)

AccessRequest = _reflection.GeneratedProtocolMessageType('AccessRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUEST,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequest)
  })
_sym_db.RegisterMessage(AccessRequest)

AccessRequestEvent = _reflection.GeneratedProtocolMessageType('AccessRequestEvent', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENT,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEvent)
  })
_sym_db.RegisterMessage(AccessRequestEvent)

RequestableResource = _reflection.GeneratedProtocolMessageType('RequestableResource', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTABLERESOURCE,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.RequestableResource)
  })
_sym_db.RegisterMessage(RequestableResource)

PrivilegesMessage = _reflection.GeneratedProtocolMessageType('PrivilegesMessage', (_message.Message,), {
  'DESCRIPTOR' : _PRIVILEGESMESSAGE,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.PrivilegesMessage)
  })
_sym_db.RegisterMessage(PrivilegesMessage)

KubernetesPrivileges = _reflection.GeneratedProtocolMessageType('KubernetesPrivileges', (_message.Message,), {
  'DESCRIPTOR' : _KUBERNETESPRIVILEGES,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.KubernetesPrivileges)
  })
_sym_db.RegisterMessage(KubernetesPrivileges)

EntraGroupPrivileges = _reflection.GeneratedProtocolMessageType('EntraGroupPrivileges', (_message.Message,), {
  'DESCRIPTOR' : _ENTRAGROUPPRIVILEGES,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.EntraGroupPrivileges)
  })
_sym_db.RegisterMessage(EntraGroupPrivileges)

OktaGroupPrivileges = _reflection.GeneratedProtocolMessageType('OktaGroupPrivileges', (_message.Message,), {
  'DESCRIPTOR' : _OKTAGROUPPRIVILEGES,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.OktaGroupPrivileges)
  })
_sym_db.RegisterMessage(OktaGroupPrivileges)

AccessRequestConfig = _reflection.GeneratedProtocolMessageType('AccessRequestConfig', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTCONFIG,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestConfig)
  })
_sym_db.RegisterMessage(AccessRequestConfig)

RequestAccessRequestConfig = _reflection.GeneratedProtocolMessageType('RequestAccessRequestConfig', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTACCESSREQUESTCONFIG,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.RequestAccessRequestConfig)
  })
_sym_db.RegisterMessage(RequestAccessRequestConfig)

_ACCESSREQUESTS = DESCRIPTOR.services_by_name['AccessRequests']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\026AccessRequestsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ACCESSREQUESTLISTREQUEST.fields_by_name['filter']._options = None
  _ACCESSREQUESTLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTLISTREQUEST._options = None
  _ACCESSREQUESTLISTREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['access_requests']._options = None
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['access_requests']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*'
  _ACCESSREQUESTLISTRESPONSE._options = None
  _ACCESSREQUESTLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['id']._options = None
  _ACCESSREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['resource_id']._options = None
  _ACCESSREQUEST.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['reason']._options = None
  _ACCESSREQUEST.fields_by_name['reason']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['workflow_id']._options = None
  _ACCESSREQUEST.fields_by_name['workflow_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['account_id']._options = None
  _ACCESSREQUEST.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['start_from']._options = None
  _ACCESSREQUEST.fields_by_name['start_from']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['valid_until']._options = None
  _ACCESSREQUEST.fields_by_name['valid_until']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['status']._options = None
  _ACCESSREQUEST.fields_by_name['status']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['status_at']._options = None
  _ACCESSREQUEST.fields_by_name['status_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['grant_id']._options = None
  _ACCESSREQUEST.fields_by_name['grant_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['duration']._options = None
  _ACCESSREQUEST.fields_by_name['duration']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['requestedDuration']._options = None
  _ACCESSREQUEST.fields_by_name['requestedDuration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['resultDuration']._options = None
  _ACCESSREQUEST.fields_by_name['resultDuration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['requester_name']._options = None
  _ACCESSREQUEST.fields_by_name['requester_name']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _ACCESSREQUEST._options = None
  _ACCESSREQUEST._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _ACCESSREQUESTEVENT.fields_by_name['id']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['request_id']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['request_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['actor_id']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['actor_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['type']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['metadata']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['metadata']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['time']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['time']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _ACCESSREQUESTEVENT._options = None
  _ACCESSREQUESTEVENT._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _REQUESTABLERESOURCE.fields_by_name['id']._options = None
  _REQUESTABLERESOURCE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['name']._options = None
  _REQUESTABLERESOURCE.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['healthy']._options = None
  _REQUESTABLERESOURCE.fields_by_name['healthy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['type']._options = None
  _REQUESTABLERESOURCE.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['authentication']._options = None
  _REQUESTABLERESOURCE.fields_by_name['authentication']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['tags']._options = None
  _REQUESTABLERESOURCE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['access']._options = None
  _REQUESTABLERESOURCE.fields_by_name['access']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['privileges']._options = None
  _REQUESTABLERESOURCE.fields_by_name['privileges']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _REQUESTABLERESOURCE.fields_by_name['privileges_requirement_status']._options = None
  _REQUESTABLERESOURCE.fields_by_name['privileges_requirement_status']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _REQUESTABLERESOURCE._options = None
  _REQUESTABLERESOURCE._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _PRIVILEGESMESSAGE.fields_by_name['kubernetes']._options = None
  _PRIVILEGESMESSAGE.fields_by_name['kubernetes']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PRIVILEGESMESSAGE.fields_by_name['entraGroups']._options = None
  _PRIVILEGESMESSAGE.fields_by_name['entraGroups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PRIVILEGESMESSAGE.fields_by_name['oktaGroups']._options = None
  _PRIVILEGESMESSAGE.fields_by_name['oktaGroups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PRIVILEGESMESSAGE._options = None
  _PRIVILEGESMESSAGE._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _KUBERNETESPRIVILEGES.fields_by_name['groups']._options = None
  _KUBERNETESPRIVILEGES.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KUBERNETESPRIVILEGES._options = None
  _KUBERNETESPRIVILEGES._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _ENTRAGROUPPRIVILEGES.fields_by_name['groups']._options = None
  _ENTRAGROUPPRIVILEGES.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ENTRAGROUPPRIVILEGES._options = None
  _ENTRAGROUPPRIVILEGES._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _OKTAGROUPPRIVILEGES.fields_by_name['groups']._options = None
  _OKTAGROUPPRIVILEGES.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _OKTAGROUPPRIVILEGES._options = None
  _OKTAGROUPPRIVILEGES._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _ACCESSREQUESTCONFIG.fields_by_name['resource_id']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCESSREQUESTCONFIG.fields_by_name['reason']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['reason']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTCONFIG.fields_by_name['start_from']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['start_from']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTCONFIG.fields_by_name['duration']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTCONFIG._options = None
  _ACCESSREQUESTCONFIG._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['resource_ids']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['resource_ids']._serialized_options = b'\030\001\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['reason']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['reason']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['start_from']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['start_from']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['duration']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['access_rules']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['access_rules']._serialized_options = b'\362\370\263\007\325\001\260\363\263\007\001\312\363\263\007\251\001\352\363\263\007\014access_rules\362\363\263\007\021\n\002go\022\013AccessRules\362\363\263\007\031\n\ngo_private\022\013AccessRules\362\363\263\007\033\n\014go_terraform\022\013AccessRules\362\363\263\007\030\n\004java\022\020List<AccessRule>\362\363\263\007\"\n\014json_gateway\022\022models.AccessRules\272\364\263\007\027accessRulesDiffSuppress\320\364\263\007\001'
  _REQUESTACCESSREQUESTCONFIG._options = None
  _REQUESTACCESSREQUESTCONFIG._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _ACCESSREQUESTS._options = None
  _ACCESSREQUESTS._serialized_options = b'\312\371\263\007\022\302\371\263\007\rAccessRequest\312\371\263\007\010\322\371\263\007\003aq-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider\312\371\263\007\005\350\371\263\007\001'
  _ACCESSREQUESTS.methods_by_name['List']._options = None
  _ACCESSREQUESTS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\030\252\363\263\007\023/v1/access-requests'
  _ACCESSREQUESTLISTREQUEST._serialized_start=133
  _ACCESSREQUESTLISTREQUEST._serialized_end=238
  _ACCESSREQUESTLISTRESPONSE._serialized_start=241
  _ACCESSREQUESTLISTRESPONSE._serialized_end=442
  _ACCESSREQUEST._serialized_start=445
  _ACCESSREQUEST._serialized_end=1088
  _ACCESSREQUESTEVENT._serialized_start=1091
  _ACCESSREQUESTEVENT._serialized_end=1340
  _REQUESTABLERESOURCE._serialized_start=1343
  _REQUESTABLERESOURCE._serialized_end=1723
  _PRIVILEGESMESSAGE._serialized_start=1726
  _PRIVILEGESMESSAGE._serialized_end=1946
  _KUBERNETESPRIVILEGES._serialized_start=1948
  _KUBERNETESPRIVILEGES._serialized_end=2025
  _ENTRAGROUPPRIVILEGES._serialized_start=2027
  _ENTRAGROUPPRIVILEGES._serialized_end=2104
  _OKTAGROUPPRIVILEGES._serialized_start=2106
  _OKTAGROUPPRIVILEGES._serialized_end=2182
  _ACCESSREQUESTCONFIG._serialized_start=2185
  _ACCESSREQUESTCONFIG._serialized_end=2380
  _REQUESTACCESSREQUESTCONFIG._serialized_start=2383
  _REQUESTACCESSREQUESTCONFIG._serialized_end=2842
  _ACCESSREQUESTS._serialized_start=2845
  _ACCESSREQUESTS._serialized_end=3062
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: identity_aliases.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16identity_aliases.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"|\n\x1aIdentityAliasCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xef\x01\n\x1bIdentityAliasCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"W\n\x17IdentityAliasGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe9\x01\n\x18IdentityAliasGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x88\x01\n\x1aIdentityAliasUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x35\n\x0eidentity_alias\x18\x03 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xef\x01\n\x1bIdentityAliasUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"]\n\x1aIdentityAliasDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb8\x01\n\x1bIdentityAliasDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"]\n\x18IdentityAliasListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd5\x01\n\x19IdentityAliasListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x37\n\x10identity_aliases\x18\x02 \x03(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x85\x02\n\rIdentityAlias\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12(\n\x0fidentity_set_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x08username\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:j\xfa\xf8\xb3\x07\x65\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07[\xa2\xf3\xb3\x07\'tf_examples/identity_alias_resource.txt\xaa\xf3\xb3\x07*tf_examples/identity_alias_data_source.txt2\x92\x05\n\x0fIdentityAliases\x12w\n\x06\x43reate\x12\x1e.v1.IdentityAliasCreateRequest\x1a\x1f.v1.IdentityAliasCreateResponse\",\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/identity-aliases\x12r\n\x03Get\x12\x1b.v1.IdentityAliasGetRequest\x1a\x1c.v1.IdentityAliasGetResponse\"0\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/identity-aliases/{id}\x12{\n\x06Update\x12\x1e.v1.IdentityAliasUpdateRequest\x1a\x1f.v1.IdentityAliasUpdateResponse\"0\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/identity-aliases/{id}\x12~\n\x06\x44\x65lete\x12\x1e.v1.IdentityAliasDeleteRequest\x1a\x1f.v1.IdentityAliasDeleteResponse\"3\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/identity-aliases/{id}\x12p\n\x04List\x12\x1c.v1.IdentityAliasListRequest\x1a\x1d.v1.IdentityAliasListResponse\"+\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/identity-aliases\x1a#\xca\xf9\xb3\x07\x12\xc2\xf9\xb3\x07\rIdentityAlias\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02i-Bk\n\x19\x63om.strongdm.api.plumbingB\x17IdentityAliasesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_IDENTITYALIASCREATEREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasCreateRequest']
_IDENTITYALIASCREATERESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasCreateResponse']
_IDENTITYALIASGETREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasGetRequest']
_IDENTITYALIASGETRESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasGetResponse']
_IDENTITYALIASUPDATEREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasUpdateRequest']
_IDENTITYALIASUPDATERESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasUpdateResponse']
_IDENTITYALIASDELETEREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasDeleteRequest']
_IDENTITYALIASDELETERESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasDeleteResponse']
_IDENTITYALIASLISTREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasListRequest']
_IDENTITYALIASLISTRESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasListResponse']
_IDENTITYALIAS = DESCRIPTOR.message_types_by_name['IdentityAlias']
IdentityAliasCreateRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASCREATEREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasCreateRequest)
  })
_sym_db.RegisterMessage(IdentityAliasCreateRequest)

IdentityAliasCreateResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASCREATERESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasCreateResponse)
  })
_sym_db.RegisterMessage(IdentityAliasCreateResponse)

IdentityAliasGetRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASGETREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasGetRequest)
  })
_sym_db.RegisterMessage(IdentityAliasGetRequest)

IdentityAliasGetResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASGETRESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasGetResponse)
  })
_sym_db.RegisterMessage(IdentityAliasGetResponse)

IdentityAliasUpdateRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASUPDATEREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasUpdateRequest)
  })
_sym_db.RegisterMessage(IdentityAliasUpdateRequest)

IdentityAliasUpdateResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASUPDATERESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasUpdateResponse)
  })
_sym_db.RegisterMessage(IdentityAliasUpdateResponse)

IdentityAliasDeleteRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASDELETEREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasDeleteRequest)
  })
_sym_db.RegisterMessage(IdentityAliasDeleteRequest)

IdentityAliasDeleteResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASDELETERESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasDeleteResponse)
  })
_sym_db.RegisterMessage(IdentityAliasDeleteResponse)

IdentityAliasListRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasListRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASLISTREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasListRequest)
  })
_sym_db.RegisterMessage(IdentityAliasListRequest)

IdentityAliasListResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasListResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASLISTRESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasListResponse)
  })
_sym_db.RegisterMessage(IdentityAliasListResponse)

IdentityAlias = _reflection.GeneratedProtocolMessageType('IdentityAlias', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIAS,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAlias)
  })
_sym_db.RegisterMessage(IdentityAlias)

_IDENTITYALIASES = DESCRIPTOR.services_by_name['IdentityAliases']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\027IdentityAliasesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _IDENTITYALIASCREATEREQUEST.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASCREATEREQUEST.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASCREATERESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASCREATERESPONSE.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASCREATERESPONSE.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASCREATERESPONSE._options = None
  _IDENTITYALIASCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASGETREQUEST.fields_by_name['id']._options = None
  _IDENTITYALIASGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASGETRESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASGETRESPONSE.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASGETRESPONSE.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASGETRESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASGETRESPONSE._options = None
  _IDENTITYALIASGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASUPDATEREQUEST.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASUPDATEREQUEST.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASUPDATERESPONSE._options = None
  _IDENTITYALIASUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASDELETEREQUEST.fields_by_name['id']._options = None
  _IDENTITYALIASDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASDELETERESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASDELETERESPONSE._options = None
  _IDENTITYALIASDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASLISTREQUEST.fields_by_name['filter']._options = None
  _IDENTITYALIASLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASLISTRESPONSE.fields_by_name['identity_aliases']._options = None
  _IDENTITYALIASLISTRESPONSE.fields_by_name['identity_aliases']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _IDENTITYALIASLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIAS.fields_by_name['id']._options = None
  _IDENTITYALIAS.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIAS.fields_by_name['account_id']._options = None
  _IDENTITYALIAS.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _IDENTITYALIAS.fields_by_name['identity_set_id']._options = None
  _IDENTITYALIAS.fields_by_name['identity_set_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _IDENTITYALIAS.fields_by_name['username']._options = None
  _IDENTITYALIAS.fields_by_name['username']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _IDENTITYALIAS._options = None
  _IDENTITYALIAS._serialized_options = b'\372\370\263\007e\250\363\263\007\001\302\363\263\007[\242\363\263\007\'tf_examples/identity_alias_resource.txt\252\363\263\007*tf_examples/identity_alias_data_source.txt'
  _IDENTITYALIASES._options = None
  _IDENTITYALIASES._serialized_options = b'\312\371\263\007\022\302\371\263\007\rIdentityAlias\312\371\263\007\007\322\371\263\007\002i-'
  _IDENTITYALIASES.methods_by_name['Create']._options = None
  _IDENTITYALIASES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\031\252\363\263\007\024/v1/identity-aliases'
  _IDENTITYALIASES.methods_by_name['Get']._options = None
  _IDENTITYALIASES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\036\252\363\263\007\031/v1/identity-aliases/{id}'
  _IDENTITYALIASES.methods_by_name['Update']._options = None
  _IDENTITYALIASES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\036\252\363\263\007\031/v1/identity-aliases/{id}'
  _IDENTITYALIASES.methods_by_name['Delete']._options = None
  _IDENTITYALIASES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\036\252\363\263\007\031/v1/identity-aliases/{id}'
  _IDENTITYALIASES.methods_by_name['List']._options = None
  _IDENTITYALIASES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\031\252\363\263\007\024/v1/identity-aliases'
  _IDENTITYALIASCREATEREQUEST._serialized_start=57
  _IDENTITYALIASCREATEREQUEST._serialized_end=181
  _IDENTITYALIASCREATERESPONSE._serialized_start=184
  _IDENTITYALIASCREATERESPONSE._serialized_end=423
  _IDENTITYALIASGETREQUEST._serialized_start=425
  _IDENTITYALIASGETREQUEST._serialized_end=512
  _IDENTITYALIASGETRESPONSE._serialized_start=515
  _IDENTITYALIASGETRESPONSE._serialized_end=748
  _IDENTITYALIASUPDATEREQUEST._serialized_start=751
  _IDENTITYALIASUPDATEREQUEST._serialized_end=887
  _IDENTITYALIASUPDATERESPONSE._serialized_start=890
  _IDENTITYALIASUPDATERESPONSE._serialized_end=1129
  _IDENTITYALIASDELETEREQUEST._serialized_start=1131
  _IDENTITYALIASDELETEREQUEST._serialized_end=1224
  _IDENTITYALIASDELETERESPONSE._serialized_start=1227
  _IDENTITYALIASDELETERESPONSE._serialized_end=1411
  _IDENTITYALIASLISTREQUEST._serialized_start=1413
  _IDENTITYALIASLISTREQUEST._serialized_end=1506
  _IDENTITYALIASLISTRESPONSE._serialized_start=1509
  _IDENTITYALIASLISTRESPONSE._serialized_end=1722
  _IDENTITYALIAS._serialized_start=1725
  _IDENTITYALIAS._serialized_end=1986
  _IDENTITYALIASES._serialized_start=1989
  _IDENTITYALIASES._serialized_end=2647
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: queries.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rqueries.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"\x7f\n\x10QueryListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xe6\x01\n\x11QueryListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12&\n\x07queries\x18\x02 \x03(\x0b\x32\t.v1.QueryB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xd3\n\n\x05Query\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\naccount_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bresource_id\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nquery_body\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tencrypted\x18\x06 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nquery_hash\x18\x07 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12.\n\x18remote_identity_username\x18\x08 \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\ttimestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0e\x65gress_node_id\x18\n \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nreplayable\x18\x0b \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12 \n\x0crecord_count\x18\x0c \x01(\x03\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rresource_type\x18\r \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0equery_category\x18\x0e \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tquery_key\x18\x0f \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rresource_name\x18\x10 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12+\n\rresource_tags\x18\x11 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x12\x61\x63\x63ount_first_name\x18\x12 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12%\n\x11\x61\x63\x63ount_last_name\x18\x13 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\raccount_email\x18\x14 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x0c\x61\x63\x63ount_tags\x18\x15 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12/\n\x0cquery_key_id\x18\x16 \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12<\n\x0c\x63ompleted_at\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12-\n\x07\x63\x61pture\x18\x18 \x01(\x0b\x32\x10.v1.QueryCaptureB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\tsource_ip\x18\x19 \x01(\tB\"\xf2\xf8\xb3\x07\x1d\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x13\xc2\xf4\xb3\x07\x0e\n\x02go\x12\x08SourceIP\x12\x34\n\x11\x61uthentication_id\x18\x1a \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12\x1a\n\x06target\x18\x1b \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x36\n\tauthzJson\x18\x1c \x01(\tB#\xf2\xf8\xb3\x07\x1e\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x14\xc2\xf4\xb3\x07\x0f\n\x02go\x12\tAuthzJSON\x12\x35\n\tclient_ip\x18\x1d \x01(\tB\"\xf2\xf8\xb3\x07\x1d\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x13\xc2\xf4\xb3\x07\x0e\n\x02go\x12\x08\x43lientIP\x12+\n\x17identity_alias_username\x18\x1e \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\rmetadata_json\x18\x1f \x01(\tB&\xf2\xf8\xb3\x07!\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x17\xc2\xf4\xb3\x07\x12\n\x02go\x12\x0cMetadataJSON:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xa3\x05\n\x0cQueryCapture\x12\x19\n\x05width\x18\x01 \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06height\x18\x02 \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07\x63ommand\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\x03\x65nv\x18\x04 \x03(\x0b\x32\x19.v1.QueryCapture.EnvEntryB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04type\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tfile_name\x18\x06 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tfile_size\x18\x07 \x01(\x03\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0e\x63lient_command\x18\x08 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x17\n\x03pod\x18\t \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tcontainer\x18\n \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0erequest_method\x18\x0b \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\x0brequest_uri\x18\x0c \x01(\tB$\xf2\xf8\xb3\x07\x1f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x15\xc2\xf4\xb3\x07\x10\n\x02go\x12\nRequestURI\x12 \n\x0crequest_body\x18\r \x01(\x0c\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x12impersonation_user\x18\x0e \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x14impersonation_groups\x18\x0f \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x10privilege_groups\x18\x10 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xa5\x01\n\x07Queries\x12W\n\x04List\x12\x14.v1.QueryListRequest\x1a\x15.v1.QueryListResponse\"\"\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x10\xaa\xf3\xb3\x07\x0b/v1/queries\x1a\x41\xca\xf9\xb3\x07\n\xc2\xf9\xb3\x07\x05Query\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x8b\x01\n\x19\x63om.strongdm.api.plumbingB\x0fQueriesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_QUERYLISTREQUEST = DESCRIPTOR.message_types_by_name['QueryListRequest']
_QUERYLISTRESPONSE = DESCRIPTOR.message_types_by_name['QueryListResponse']
_QUERY = DESCRIPTOR.message_types_by_name['Query']
_QUERYCAPTURE = DESCRIPTOR.message_types_by_name['QueryCapture']
_QUERYCAPTURE_ENVENTRY = _QUERYCAPTURE.nested_types_by_name['EnvEntry']
QueryListRequest = _reflection.GeneratedProtocolMessageType('QueryListRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLISTREQUEST,
  '__module__' : 'queries_pb2'
  # @@protoc_insertion_point(class_scope:v1.QueryListRequest)
  })
_sym_db.RegisterMessage(QueryListRequest)

QueryListResponse = _reflection.GeneratedProtocolMessageType('QueryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLISTRESPONSE,
  '__module__' : 'queries_pb2'
  # @@protoc_insertion_point(class_scope:v1.QueryListResponse)
  })
_sym_db.RegisterMessage(QueryListResponse)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'queries_pb2'
  # @@protoc_insertion_point(class_scope:v1.Query)
  })
_sym_db.RegisterMessage(Query)

QueryCapture = _reflection.GeneratedProtocolMessageType('QueryCapture', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUERYCAPTURE_ENVENTRY,
    '__module__' : 'queries_pb2'
    # @@protoc_insertion_point(class_scope:v1.QueryCapture.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _QUERYCAPTURE,
  '__module__' : 'queries_pb2'
  # @@protoc_insertion_point(class_scope:v1.QueryCapture)
  })
_sym_db.RegisterMessage(QueryCapture)
_sym_db.RegisterMessage(QueryCapture.EnvEntry)

_QUERIES = DESCRIPTOR.services_by_name['Queries']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\017QueriesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _QUERYLISTREQUEST.fields_by_name['filter']._options = None
  _QUERYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYLISTREQUEST._options = None
  _QUERYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _QUERYLISTRESPONSE.fields_by_name['queries']._options = None
  _QUERYLISTRESPONSE.fields_by_name['queries']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _QUERYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _QUERYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _QUERYLISTRESPONSE._options = None
  _QUERYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _QUERY.fields_by_name['id']._options = None
  _QUERY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['account_id']._options = None
  _QUERY.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['resource_id']._options = None
  _QUERY.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['query_body']._options = None
  _QUERY.fields_by_name['query_body']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['duration']._options = None
  _QUERY.fields_by_name['duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['encrypted']._options = None
  _QUERY.fields_by_name['encrypted']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['query_hash']._options = None
  _QUERY.fields_by_name['query_hash']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['remote_identity_username']._options = None
  _QUERY.fields_by_name['remote_identity_username']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['timestamp']._options = None
  _QUERY.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['egress_node_id']._options = None
  _QUERY.fields_by_name['egress_node_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['replayable']._options = None
  _QUERY.fields_by_name['replayable']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['record_count']._options = None
  _QUERY.fields_by_name['record_count']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['resource_type']._options = None
  _QUERY.fields_by_name['resource_type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['query_category']._options = None
  _QUERY.fields_by_name['query_category']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['query_key']._options = None
  _QUERY.fields_by_name['query_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['resource_name']._options = None
  _QUERY.fields_by_name['resource_name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['resource_tags']._options = None
  _QUERY.fields_by_name['resource_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['account_first_name']._options = None
  _QUERY.fields_by_name['account_first_name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['account_last_name']._options = None
  _QUERY.fields_by_name['account_last_name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['account_email']._options = None
  _QUERY.fields_by_name['account_email']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['account_tags']._options = None
  _QUERY.fields_by_name['account_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['query_key_id']._options = None
  _QUERY.fields_by_name['query_key_id']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _QUERY.fields_by_name['completed_at']._options = None
  _QUERY.fields_by_name['completed_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['capture']._options = None
  _QUERY.fields_by_name['capture']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['source_ip']._options = None
  _QUERY.fields_by_name['source_ip']._serialized_options = b'\362\370\263\007\035\260\363\263\007\001\312\363\263\007\023\302\364\263\007\016\n\002go\022\010SourceIP'
  _QUERY.fields_by_name['authentication_id']._options = None
  _QUERY.fields_by_name['authentication_id']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _QUERY.fields_by_name['target']._options = None
  _QUERY.fields_by_name['target']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['authzJson']._options = None
  _QUERY.fields_by_name['authzJson']._serialized_options = b'\362\370\263\007\036\260\363\263\007\001\312\363\263\007\024\302\364\263\007\017\n\002go\022\tAuthzJSON'
  _QUERY.fields_by_name['client_ip']._options = None
  _QUERY.fields_by_name['client_ip']._serialized_options = b'\362\370\263\007\035\260\363\263\007\001\312\363\263\007\023\302\364\263\007\016\n\002go\022\010ClientIP'
  _QUERY.fields_by_name['identity_alias_username']._options = None
  _QUERY.fields_by_name['identity_alias_username']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERY.fields_by_name['metadata_json']._options = None
  _QUERY.fields_by_name['metadata_json']._serialized_options = b'\362\370\263\007!\260\363\263\007\001\312\363\263\007\027\302\364\263\007\022\n\002go\022\014MetadataJSON'
  _QUERY._options = None
  _QUERY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _QUERYCAPTURE_ENVENTRY._options = None
  _QUERYCAPTURE_ENVENTRY._serialized_options = b'8\001'
  _QUERYCAPTURE.fields_by_name['width']._options = None
  _QUERYCAPTURE.fields_by_name['width']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['height']._options = None
  _QUERYCAPTURE.fields_by_name['height']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['command']._options = None
  _QUERYCAPTURE.fields_by_name['command']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['env']._options = None
  _QUERYCAPTURE.fields_by_name['env']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['type']._options = None
  _QUERYCAPTURE.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['file_name']._options = None
  _QUERYCAPTURE.fields_by_name['file_name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['file_size']._options = None
  _QUERYCAPTURE.fields_by_name['file_size']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['client_command']._options = None
  _QUERYCAPTURE.fields_by_name['client_command']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['pod']._options = None
  _QUERYCAPTURE.fields_by_name['pod']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['container']._options = None
  _QUERYCAPTURE.fields_by_name['container']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['request_method']._options = None
  _QUERYCAPTURE.fields_by_name['request_method']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['request_uri']._options = None
  _QUERYCAPTURE.fields_by_name['request_uri']._serialized_options = b'\362\370\263\007\037\260\363\263\007\001\312\363\263\007\025\302\364\263\007\020\n\002go\022\nRequestURI'
  _QUERYCAPTURE.fields_by_name['request_body']._options = None
  _QUERYCAPTURE.fields_by_name['request_body']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['impersonation_user']._options = None
  _QUERYCAPTURE.fields_by_name['impersonation_user']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['impersonation_groups']._options = None
  _QUERYCAPTURE.fields_by_name['impersonation_groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE.fields_by_name['privilege_groups']._options = None
  _QUERYCAPTURE.fields_by_name['privilege_groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _QUERYCAPTURE._options = None
  _QUERYCAPTURE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _QUERIES._options = None
  _QUERIES._serialized_options = b'\312\371\263\007\n\302\371\263\007\005Query\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _QUERIES.methods_by_name['List']._options = None
  _QUERIES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\020\252\363\263\007\013/v1/queries'
  _QUERYLISTREQUEST._serialized_start=125
  _QUERYLISTREQUEST._serialized_end=252
  _QUERYLISTRESPONSE._serialized_start=255
  _QUERYLISTRESPONSE._serialized_end=485
  _QUERY._serialized_start=488
  _QUERY._serialized_end=1851
  _QUERYCAPTURE._serialized_start=1854
  _QUERYCAPTURE._serialized_end=2529
  _QUERYCAPTURE_ENVENTRY._serialized_start=2435
  _QUERYCAPTURE_ENVENTRY._serialized_end=2477
  _QUERIES._serialized_start=2532
  _QUERIES._serialized_end=2697
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Code generated by protogen. DO NOT EDIT.


class RPCError(Exception):
    '''A generic RPC error'''
    def __init__(self, msg, code):
        self.msg = msg
        self.code = code


class AlreadyExistsError(RPCError):
    '''Used when an entity already exists in the system'''
    def __init__(self, msg):
        super().__init__(msg, 6)


class NotFoundError(RPCError):
    '''Used when an entity does not exist in the system'''
    def __init__(self, msg):
        super().__init__(msg, 5)


class BadRequestError(RPCError):
    '''Identifies a bad request sent by the client'''
    def __init__(self, msg):
        super().__init__(msg, 3)


class AuthenticationError(RPCError):
    '''Used to specify an authentication failure condition'''
    def __init__(self, msg):
        super().__init__(msg, 16)


class PermissionError(RPCError):
    '''Used to specify a permissions violation'''
    def __init__(self, msg):
        super().__init__(msg, 7)


class InternalError(RPCError):
    '''Used to specify an internal system error'''
    def __init__(self, msg):
        super().__init__(msg, 13)


class RateLimitError(RPCError):
    '''Used when rate limit is exceeded'''
    def __init__(self, msg, rate_limit):
        super().__init__(msg, 8)
        self.rate_limit = rate_limit


class TimeoutError(RPCError):
    '''Used when a request takes too long'''
    def __init__(self):
        super().__init__('deadline exceeded', 4)


class UnknownError(RPCError):
    '''Generic wrapper that indicates an unknown internal error in the SDK.'''
    def __init__(self, msg):
        super().__init__(msg, 2)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import managed_secrets_pb2 as managed__secrets__pb2


class ManagedSecretsStub(object):
    """ManagedSecret is a private vertical for creating, reading, updating,
    deleting, listing and rotating the managed secrets in the secrets engines as
    an authenticated user.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/v1.ManagedSecrets/List',
                request_serializer=managed__secrets__pb2.ManagedSecretListRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretListResponse.FromString,
                )
        self.ListByActor = channel.unary_unary(
                '/v1.ManagedSecrets/ListByActor',
                request_serializer=managed__secrets__pb2.ManagedSecretListRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretListResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/v1.ManagedSecrets/Create',
                request_serializer=managed__secrets__pb2.ManagedSecretCreateRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretCreateResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/v1.ManagedSecrets/Update',
                request_serializer=managed__secrets__pb2.ManagedSecretUpdateRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretUpdateResponse.FromString,
                )
        self.Rotate = channel.unary_unary(
                '/v1.ManagedSecrets/Rotate',
                request_serializer=managed__secrets__pb2.ManagedSecretRotateRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretRotateResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/v1.ManagedSecrets/Delete',
                request_serializer=managed__secrets__pb2.ManagedSecretDeleteRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretDeleteResponse.FromString,
                )
        self.ForceDelete = channel.unary_unary(
                '/v1.ManagedSecrets/ForceDelete',
                request_serializer=managed__secrets__pb2.ManagedSecretDeleteRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretDeleteResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/v1.ManagedSecrets/Get',
                request_serializer=managed__secrets__pb2.ManagedSecretGetRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretGetResponse.FromString,
                )
        self.Retrieve = channel.unary_unary(
                '/v1.ManagedSecrets/Retrieve',
                request_serializer=managed__secrets__pb2.ManagedSecretRetrieveRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretRetrieveResponse.FromString,
                )
        self.Validate = channel.unary_unary(
                '/v1.ManagedSecrets/Validate',
                request_serializer=managed__secrets__pb2.ManagedSecretValidateRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretValidateResponse.FromString,
                )
        self.Logs = channel.unary_unary(
                '/v1.ManagedSecrets/Logs',
                request_serializer=managed__secrets__pb2.ManagedSecretLogsRequest.SerializeToString,
                response_deserializer=managed__secrets__pb2.ManagedSecretLogsResponse.FromString,
                )


class ManagedSecretsServicer(object):
    """ManagedSecret is a private vertical for creating, reading, updating,
    deleting, listing and rotating the managed secrets in the secrets engines as
    an authenticated user.
    """

    def List(self, request, context):
        """List returns Managed Secrets from a Secret Engine.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListByActor(self, request, context):
        """List returns Managed Secrets for an Actor from a Secret Engine.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Create creates a Managed Secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update updates a Managed Secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rotate(self, request, context):
        """Rotate forces rotation of Managed Secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete deletes a Managed Secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ForceDelete(self, request, context):
        """ForceDelete deletes a Managed Secret regardless of errors on external system 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get gets details of a Managed Secret without sensitive data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Retrieve returns Managed Secret with sensitive data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Validate(self, request, context):
        """Validate returns the result of testing the stored credential against the
        secret engine.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logs(self, request, context):
        """Logs returns the audit records for the managed secret. This may be replaced
        in the future.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ManagedSecretsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=managed__secrets__pb2.ManagedSecretListRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretListResponse.SerializeToString,
            ),
            'ListByActor': grpc.unary_unary_rpc_method_handler(
                    servicer.ListByActor,
                    request_deserializer=managed__secrets__pb2.ManagedSecretListRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretListResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=managed__secrets__pb2.ManagedSecretCreateRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretCreateResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=managed__secrets__pb2.ManagedSecretUpdateRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretUpdateResponse.SerializeToString,
            ),
            'Rotate': grpc.unary_unary_rpc_method_handler(
                    servicer.Rotate,
                    request_deserializer=managed__secrets__pb2.ManagedSecretRotateRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretRotateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=managed__secrets__pb2.ManagedSecretDeleteRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretDeleteResponse.SerializeToString,
            ),
            'ForceDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.ForceDelete,
                    request_deserializer=managed__secrets__pb2.ManagedSecretDeleteRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretDeleteResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=managed__secrets__pb2.ManagedSecretGetRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretGetResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=managed__secrets__pb2.ManagedSecretRetrieveRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretRetrieveResponse.SerializeToString,
            ),
            'Validate': grpc.unary_unary_rpc_method_handler(
                    servicer.Validate,
                    request_deserializer=managed__secrets__pb2.ManagedSecretValidateRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretValidateResponse.SerializeToString,
            ),
            'Logs': grpc.unary_unary_rpc_method_handler(
                    servicer.Logs,
                    request_deserializer=managed__secrets__pb2.ManagedSecretLogsRequest.FromString,
                    response_serializer=managed__secrets__pb2.ManagedSecretLogsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.ManagedSecrets', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ManagedSecrets(object):
    """ManagedSecret is a private vertical for creating, reading, updating,
    deleting, listing and rotating the managed secrets in the secrets engines as
    an authenticated user.
    """

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/List',
            managed__secrets__pb2.ManagedSecretListRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListByActor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/ListByActor',
            managed__secrets__pb2.ManagedSecretListRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Create',
            managed__secrets__pb2.ManagedSecretCreateRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Update',
            managed__secrets__pb2.ManagedSecretUpdateRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Rotate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Rotate',
            managed__secrets__pb2.ManagedSecretRotateRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretRotateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Delete',
            managed__secrets__pb2.ManagedSecretDeleteRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ForceDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/ForceDelete',
            managed__secrets__pb2.ManagedSecretDeleteRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Get',
            managed__secrets__pb2.ManagedSecretGetRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Retrieve',
            managed__secrets__pb2.ManagedSecretRetrieveRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretRetrieveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Validate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Validate',
            managed__secrets__pb2.ManagedSecretValidateRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretValidateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ManagedSecrets/Logs',
            managed__secrets__pb2.ManagedSecretLogsRequest.SerializeToString,
            managed__secrets__pb2.ManagedSecretLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
